# tmux-control

configure and control tmux

# note

code in experimental state -- check back soon

# setup

```Bash
sudo pip install tmuxcontrol
```

# documentation and help

```Bash
tmux-control.py --help
```
